# elife-article

eLife article objects.

## Requirements

As specified in `setup.py` in the `install_requires` property.

## License

Licensed under [MIT](https://opensource.org/licenses/mit-license.php).
